@@ -34,7 +34,8 @@ _LOGGER = Logger(__name__)
 class Tado:
     """Interacts with a Tado thermostat via public my.tado.com API.
 
-    Example usage: http = Http('me@somewhere.com', 'mypasswd')
+    Example usage: http = Http()
+                   http.device_activation() # Activate the device
                    t = Tado(http)
                    t.get_climate(1) # Get climate, zone 1.
     """
@@ -619,4 +620,4 @@ class Tado:
         request.endpoint = Endpoint.MINDER
         request.params = {"from": date}
 
-        return self._http.request(request)
\ No newline at end of file
+        return self._http.request(request)
